@@ -17,25 +17,30 @@
 
 from __future__ import division, print_function, absolute_import
 
+import logging
 import traceback
 
+from hypothesis import Verbosity, settings
 from hypothesis.errors import CleanupFailed, InvalidArgument, \
     UnsatisfiedAssumption
 from hypothesis.reporting import report
 from hypothesis.utils.dynamicvariables import DynamicVariable
 
+if False:
+    from typing import Any, AnyStr  # noqa
+
 
 def reject():
     raise UnsatisfiedAssumption()
 
 
 def assume(condition):
+    # type: (Any) -> bool
     """Calling ``assume`` is like an :ref:`assert <python:assert>` that marks
     the example as bad, rather than failing the test.
 
     This allows you to specify properties that you *assume* will be
     true, and let Hypothesis try to avoid similar examples in future.
-
     """
     if not condition:
         raise UnsatisfiedAssumption()
@@ -62,14 +67,20 @@ class BuildContext(object):
         self.close_on_capture = close_on_capture
         self.close_on_del = False
         self.notes = []
+        self.original_logging_disable = logging.NOTSET
 
     def __enter__(self):
+        if not self.is_final:
+            self.original_logging_disable = logging.root.manager.disable
+            logging.disable(logging.CRITICAL)
         self.assign_variable = _current_build_context.with_value(self)
         self.assign_variable.__enter__()
         return self
 
     def __exit__(self, exc_type, exc_value, tb):
         self.assign_variable.__exit__(exc_type, exc_value, tb)
+        if not self.is_final:
+            logging.disable(self.original_logging_disable)
         if self.close() and exc_type is None:
             raise CleanupFailed()
 
@@ -95,7 +106,6 @@ def cleanup(teardown):
     Inside a test this isn't very interesting, because you can just use
     a finally block, but note that you can use this inside map, flatmap,
     etc. in order to e.g. insist that a value is closed at the end.
-
     """
     context = _current_build_context.value
     if context is None:
@@ -105,23 +115,24 @@ def cleanup(teardown):
 
 
 def note(value):
+    # type: (AnyStr) -> None
     """Report this value in the final execution."""
     context = _current_build_context.value
     if context is None:
         raise InvalidArgument(
             'Cannot make notes outside of a test')
     context.notes.append(value)
-    if context.is_final:
+    if context.is_final or settings.default.verbosity >= Verbosity.verbose:
         report(value)
 
 
 def event(value):
+    # type: (AnyStr) -> None
     """Record an event that occurred this test. Statistics on number of test
     runs with each event will be reported at the end if you run Hypothesis in
     statistics reporting mode.
 
     Events should be strings or convertible to them.
-
     """
     context = _current_build_context.value
     if context is None:
